// This file is auto-updated by xtasks/release-plz
// Current star count from GitHub API
export default {
  load() {
    return {
      stars: "21k",
    };
  },
};
